==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/pl_PL/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software version</source>
        <translation>Wersja oprogramowania</translation>
    </message>
    <message>
        <source>Last activity</source>
        <translation>Ostatnia aktywność</translation>
    </message>
    <message>
        <source>Entity time</source>
        <translation>Czas kontaktu</translation>
    </message>
    <message>
        <source>Software: %1 %2</source>
        <translation>Oprogramowanie: %1 %2</translation>
    </message>
    <message>
        <source>Offline since: %1</source>
        <translation>Odłączony od: %1</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Czas kontaktu: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Informacja o oprogramowaniu</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Oprogramowanie</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Wersja oprogramowania</translation>
    </message>
    <message>
        <source>OS</source>
        <translatorcomment>OS</translatorcomment>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Wersja OS</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Informacja o kliencie</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Pozwala wysyłać i odbierać informacje o wersji oprogramowania, czasie lokalnym i ostatniej aktywności kontaktu</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Obsługa wymiany informacji na temat wersji oprogramowania</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Ostatnia Aktywność</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Obsługa wymiany informacji o ostatniej aktywności użytkownika</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Czas kontaktu</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Obsługa wymiany informacji na temat czasu lokalnego użytkownika</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Informacja o kliencie - %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Software Version&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Wersja oprogramowania&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>OS:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Not loaded&lt;br&gt;</source>
        <translation>Nie załadowano&lt;br&gt;</translation>
    </message>
    <message>
        <source>Loading ...&lt;br&gt;</source>
        <translation>Ładuję...&lt;br&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Last Activity&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Ostatnia aktywność&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>&lt;b&gt;Entity time&lt;/b&gt;&lt;br&gt;</source>
        <translation>&lt;b&gt;Lokalny czas kontaktu&lt;/b&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Czas:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Różnica:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Ping, msek:</translation>
    </message>
    <message>
        <source>Not available&lt;br&gt;</source>
        <translation>Niedostępny&lt;br&gt;</translation>
    </message>
    <message>
        <source>%1y </source>
        <translation>%1r </translation>
    </message>
    <message>
        <source>%1d </source>
        <translation>%1d </translation>
    </message>
    <message>
        <source>%1h </source>
        <translation>%1g </translation>
    </message>
    <message>
        <source>%1m </source>
        <translation>%1m </translation>
    </message>
    <message>
        <source>%1s</source>
        <translation>%1s</translation>
    </message>
</context>
<context>
    <name>MiscOptionsWidgetClass</name>
    <message>
        <source>Share information about OS version</source>
        <translation>Udostępniaj informację o wersji systemu</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/pl_PL/clientinfo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL" sourcelanguage="en">
<context>
    <name>ClientInfo</name>
    <message>
        <source>Software: %1 %2</source>
        <translation>Oprogramowanie: %1 %2</translation>
    </message>
    <message>
        <source>Entity time: %1</source>
        <translation>Czas kontaktu: %1</translation>
    </message>
    <message>
        <source>Software information</source>
        <translation>Informacja o oprogramowaniu</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Oprogramowanie</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Wersja oprogramowania</translation>
    </message>
    <message>
        <source>OS</source>
        <translatorcomment>OS</translatorcomment>
        <translation>ОС</translation>
    </message>
    <message>
        <source>OS Version</source>
        <translation>Wersja OS</translation>
    </message>
    <message>
        <source>Client Information</source>
        <translation>Informacja o kliencie</translation>
    </message>
    <message>
        <source>Allows to send and receive information about the version of the application, the local time and the last activity of contact</source>
        <translation>Pozwala wysyłać i odbierać informacje o wersji oprogramowania, czasie lokalnym i ostatniej aktywności kontaktu</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the application version</source>
        <translation>Obsługa wymiany informacji na temat wersji oprogramowania</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Ostatnia Aktywność</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user last activity</source>
        <translation>Obsługa wymiany informacji o ostatniej aktywności użytkownika</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Czas kontaktu</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user local time</source>
        <translation>Obsługa wymiany informacji na temat czasu lokalnego użytkownika</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Czas pracy serwisu</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Czas bezczynności</translation>
    </message>
</context>
<context>
    <name>ClientInfoDialog</name>
    <message>
        <source>Client info - %1</source>
        <translation>Informacja o kliencie - %1</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>OS:</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Czas:</translation>
    </message>
    <message>
        <source>Delta:</source>
        <translation>Różnica:</translation>
    </message>
    <message>
        <source>Ping, msec:</source>
        <translation>Ping, msek:</translation>
    </message>
    <message>
        <source>Software Version</source>
        <translation>Wersja oprogramowania</translation>
    </message>
    <message>
        <source>Service Uptime</source>
        <translation>Czas pracy serwisu</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <translation>Ostatnia Aktywność</translation>
    </message>
    <message>
        <source>Idle Time</source>
        <translation>Czas bezczynności</translation>
    </message>
    <message>
        <source>Uptime:</source>
        <translation>Aktywny:</translation>
    </message>
    <message>
        <source>Inactive:</source>
        <translation>Nie aktywny:</translation>
    </message>
    <message>
        <source>Idle:</source>
        <translation>Bezczynny:</translation>
    </message>
    <message>
        <source>Entity Time</source>
        <translation>Czas kontaktu</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nie dostępny</translation>
    </message>
    <message>
        <source>%1y</source>
        <comment>years</comment>
        <translation>%1r</translation>
    </message>
    <message>
        <source>%1d</source>
        <comment>days</comment>
        <translation>%1d</translation>
    </message>
    <message>
        <source>%1h</source>
        <comment>hours</comment>
        <translation>%1g</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>minutes</comment>
        <translation>%1m</translation>
    </message>
    <message>
        <source>%1s</source>
        <comment>seconds</comment>
        <translation>%1s</translation>
    </message>
    <message>
        <source>Waiting response...</source>
        <translation>Oczekiwanie na odpowiedź...</translation>
    </message>
</context>
<context>
    <name>MiscOptionsWidgetClass</name>
    <message>
        <source>Share information about OS version</source>
        <translation>Udostępniaj informację o wersji systemu</translation>
    </message>
</context>
</TS>
